diff --git a/core/assets/vendor/jquery-once/jquery.once.min.js b/core/assets/vendor/jquery-once/jquery.once.min.js
index d15b280cfc..56c4ba17b5 100644
--- a/core/assets/vendor/jquery-once/jquery.once.min.js
+++ b/core/assets/vendor/jquery-once/jquery.once.min.js
@@ -1,8 +1,8 @@
 /*!
- * jQuery Once v2.1.1 - http://github.com/robloach/jquery-once
+ * jQuery Once v2.2.0 - http://github.com/robloach/jquery-once
  * @license MIT, GPL-2.0
  *   http://opensource.org/licenses/MIT
  *   http://opensource.org/licenses/GPL-2.0
  */
-(function(e){"use strict";if(typeof exports==="object"){e(require("jquery"))}else if(typeof define==="function"&&define.amd){define(["jquery"],e)}else{e(jQuery)}})(function(e){"use strict";var n=function(e){e=e||"once";if(typeof e!=="string"){throw new Error("The jQuery Once id parameter must be a string")}return e};e.fn.once=function(t){var r="jquery-once-"+n(t);return this.filter(function(){return e(this).data(r)!==true}).data(r,true)};e.fn.removeOnce=function(e){return this.findOnce(e).removeData("jquery-once-"+n(e))};e.fn.findOnce=function(t){var r="jquery-once-"+n(t);return this.filter(function(){return e(this).data(r)===true})}});
+(function(e){"use strict";if(typeof exports==="object"){e(require("jquery"))}else if(typeof define==="function"&&define.amd){define(["jquery"],e)}else{e(jQuery)}})(function(e){"use strict";var n=function(e){e=e||"once";if(typeof e!=="string"){throw new TypeError("The jQuery Once id parameter must be a string")}return e};e.fn.once=function(t){var r="jquery-once-"+n(t);return this.filter(function(){return e(this).data(r)!==true}).data(r,true)};e.fn.removeOnce=function(e){return this.findOnce(e).removeData("jquery-once-"+n(e))};e.fn.findOnce=function(t){var r="jquery-once-"+n(t);return this.filter(function(){return e(this).data(r)===true})}});
 //# sourceMappingURL=jquery.once.min.js.map
\ No newline at end of file
diff --git a/core/assets/vendor/jquery-once/jquery.once.min.js.map b/core/assets/vendor/jquery-once/jquery.once.min.js.map
index 1db77fa011..2d48c5cbed 100644
--- a/core/assets/vendor/jquery-once/jquery.once.min.js.map
+++ b/core/assets/vendor/jquery-once/jquery.once.min.js.map
@@ -1 +1 @@
-{"version":3,"file":"jquery.once.min.js","sources":["jquery.once.js"],"names":["factory","exports","require","define","amd","jQuery","$","checkId","id","Error","fn","once","name","this","filter","data","removeOnce","findOnce","removeData"],"mappings":";;;;;;CAgBC,SAAUA,GACT,YAEA,UAAWC,WAAY,SAAU,CAE/BD,EAAQE,QAAQ,eACX,UAAWC,UAAW,YAAcA,OAAOC,IAAK,CAGrDD,QAAQ,UAAWH,OACd,CAGLA,EAAQK,WAEV,SAAUC,GACV,YAaA,IAAIC,GAAU,SAAUC,GACtBA,EAAKA,GAAM,MACX,UAAWA,KAAO,SAAU,CAC1B,KAAM,IAAIC,OAAM,iDAElB,MAAOD,GAyCTF,GAAEI,GAAGC,KAAO,SAAUH,GAEpB,GAAII,GAAO,eAAiBL,EAAQC,EAGpC,OAAOK,MAAKC,OAAO,WACjB,MAAOR,GAAEO,MAAME,KAAKH,KAAU,OAC7BG,KAAKH,EAAM,MAiChBN,GAAEI,GAAGM,WAAa,SAAUR,GAE1B,MAAOK,MAAKI,SAAST,GAAIU,WAAW,eAAiBX,EAAQC,IAkC/DF,GAAEI,GAAGO,SAAW,SAAUT,GAExB,GAAII,GAAO,eAAiBL,EAAQC,EAEpC,OAAOK,MAAKC,OAAO,WACjB,MAAOR,GAAEO,MAAME,KAAKH,KAAU"}
\ No newline at end of file
+{"version":3,"sources":["jquery.once.js"],"names":["factory","exports","require","define","amd","jQuery","$","checkId","id","TypeError","fn","once","name","this","filter","data","removeOnce","findOnce","removeData"],"mappings":";;;;;;CAgBA,SAAWA,GACT,aAEA,UAAWC,UAAY,SAAU,CAE/BD,EAAQE,QAAQ,gBACX,UAAWC,SAAW,YAAcA,OAAOC,IAAK,CAGrDD,QAAQ,UAAWH,OACd,CAGLA,EAAQK,WAET,SAAUC,GACX,aAaA,IAAIC,EAAU,SAAUC,GACtBA,EAAKA,GAAM,OACX,UAAWA,IAAO,SAAU,CAC1B,MAAM,IAAIC,UAAU,iDAEtB,OAAOD,GAyCTF,EAAEI,GAAGC,KAAO,SAAUH,GAEpB,IAAII,EAAO,eAAiBL,EAAQC,GAGpC,OAAOK,KAAKC,OAAO,WACjB,OAAOR,EAAEO,MAAME,KAAKH,KAAU,OAC7BG,KAAKH,EAAM,OAiChBN,EAAEI,GAAGM,WAAa,SAAUR,GAE1B,OAAOK,KAAKI,SAAST,GAAIU,WAAW,eAAiBX,EAAQC,KAkC/DF,EAAEI,GAAGO,SAAW,SAAUT,GAExB,IAAII,EAAO,eAAiBL,EAAQC,GAEpC,OAAOK,KAAKC,OAAO,WACjB,OAAOR,EAAEO,MAAME,KAAKH,KAAU","file":"jquery.once.min.js"}
\ No newline at end of file
diff --git a/core/core.libraries.yml b/core/core.libraries.yml
index 935c814668..eea3afa890 100644
--- a/core/core.libraries.yml
+++ b/core/core.libraries.yml
@@ -382,7 +382,7 @@ jquery.form:
   version: "4.21"
   license:
     name: GNU-GPL-2.0-or-later
-    url: https://github.com/jquery-form/form/blob/master/LICENSE-LGPLv3
+    url: https://raw.githubusercontent.com/jquery-form/form/master/LICENSE-LGPLv3
     gpl-compatible: true
   js:
     assets/vendor/jquery-form/jquery.form.min.js: { minified: true }
@@ -404,10 +404,10 @@ jquery.joyride:
 
 jquery.once:
   remote: https://github.com/RobLoach/jquery-once
-  version: "2.1.1"
+  version: "2.2.0"
   license:
     name: GNU-GPL-2.0-or-later
-    url: https://github.com/RobLoach/jquery-once/blob/2.1.1/LICENSE.md
+    url: https://raw.githubusercontent.com/RobLoach/jquery-once/2.2.0/LICENSE.md
     gpl-compatible: true
   js:
     assets/vendor/jquery-once/jquery.once.min.js: { weight: -19, minified: true }

diff --git a/core/assets/vendor/jquery-once/jquery.once.js b/core/assets/vendor/jquery-once/jquery.once.js
index 471dd535cd..f0ed4d0a4b 100644
--- a/core/assets/vendor/jquery-once/jquery.once.js
+++ b/core/assets/vendor/jquery-once/jquery.once.js
@@ -1,5 +1,5 @@
 /*!
- * jQuery Once v2.1.1 - http://github.com/robloach/jquery-once
+ * jQuery Once v2.2.0 - http://github.com/robloach/jquery-once
  * @license MIT, GPL-2.0
  *   http://opensource.org/licenses/MIT
  *   http://opensource.org/licenses/GPL-2.0
@@ -29,7 +29,7 @@
     /* globals jQuery */
     factory(jQuery);
   }
-}(function ($) {
+})(function ($) {
   'use strict';
 
   /**
@@ -40,13 +40,13 @@
    *
    * @returns The valid ID name.
    *
    * @throws Error when an ID is provided, but not a string.
    * @private
    */
   var checkId = function (id) {
     id = id || 'once';
     if (typeof id !== 'string') {
-      throw new Error('The jQuery Once id parameter must be a string');
+      throw new TypeError('The jQuery Once id parameter must be a string');
     }
     return id;
   };
@@ -173,4 +173,4 @@
       return $(this).data(name) === true;
     });
   };
-}));
+});
@@ -40,13 +40,13 @@
    * @returns The valid ID name.
    *
-   * @throws Error when an ID is provided, but not a string.
+   * @throws TypeError when an ID is provided, but not a string.
    * @private
    */